==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/pa.py <==
info = {
    "name": "pa",
    "date_order": "DMY",
    "january": [
        "ਜਨਵਰੀ",
        "ਜਨ"
    ],
    "february": [
        "ਫ਼ਰਵਰੀ",
        "ਫ਼ਰ"
    ],
    "march": [
        "ਮਾਰਚ"
    ],
    "april": [
        "ਅਪ੍ਰੈਲ",
        "ਅਪ੍ਰੈ"
    ],
    "may": [
        "ਮਈ"
    ],
    "june": [
        "ਜੂਨ"
    ],
    "july": [
        "ਜੁਲਾਈ",
        "ਜੁਲਾ"
    ],
    "august": [
        "ਅਗਸਤ",
        "ਅਗ"
    ],
    "september": [
        "ਸਤੰਬਰ",
        "ਸਤੰ"
    ],
    "october": [
        "ਅਕਤੂਬਰ",
        "ਅਕਤੂ"
    ],
    "november": [
        "ਨਵੰਬਰ",
        "ਨਵੰ"
    ],
    "december": [
        "ਦਸੰਬਰ",
        "ਦਸੰ"
    ],
    "monday": [
        "ਸੋਮਵਾਰ",
        "ਸੋਮ"
    ],
    "tuesday": [
        "ਮੰਗਲਵਾਰ",
        "ਮੰਗਲ"
    ],
    "wednesday": [
        "ਬੁੱਧਵਾਰ",
        "ਬੁੱਧ"
    ],
    "thursday": [
        "ਵੀਰਵਾਰ",
        "ਵੀਰ"
    ],
    "friday": [
        "ਸ਼ੁੱਕਰਵਾਰ",
        "ਸ਼ੁੱਕਰ"
    ],
    "saturday": [
        "ਸ਼ਨਿੱਚਰਵਾਰ",
        "ਸ਼ਨਿੱਚਰ"
    ],
    "sunday": [
        "ਐਤਵਾਰ",
        "ਐਤ"
    ],
    "am": [
        "ਪੂਦੁ"
    ],
    "pm": [
        "ਬਾਦੁ"
    ],
    "year": [
        "ਸਾਲ"
    ],
    "month": [
        "ਮਹੀਨਾ"
    ],
    "week": [
        "ਹਫ਼ਤਾ"
    ],
    "day": [
        "ਦਿਨ"
    ],
    "hour": [
        "ਘੰਟਾ",
        "ਘੰ"
    ],
    "minute": [
        "ਮਿੰਟ"
    ],
    "second": [
        "ਸਕਿੰਟ"
    ],
    "relative-type": {
        "1 year ago": [
            "ਪਿਛਲਾ ਸਾਲ"
        ],
        "0 year ago": [
            "ਇਹ ਸਾਲ"
        ],
        "in 1 year": [
            "ਅਗਲਾ ਸਾਲ"
        ],
        "1 month ago": [
            "ਪਿਛਲਾ ਮਹੀਨਾ"
        ],
        "0 month ago": [
            "ਇਹ ਮਹੀਨਾ"
        ],
        "in 1 month": [
            "ਅਗਲਾ ਮਹੀਨਾ"
        ],
        "1 week ago": [
            "ਪਿਛਲਾ ਹਫ਼ਤਾ"
        ],
        "0 week ago": [
            "ਇਹ ਹਫ਼ਤਾ"
        ],
        "in 1 week": [
            "ਅਗਲਾ ਹਫ਼ਤਾ"
        ],
        "1 day ago": [
            "ਬੀਤਿਆ ਕੱਲ੍ਹ"
        ],
        "0 day ago": [
            "ਅੱਜ"
        ],
        "in 1 day": [
            "ਭਲਕੇ"
        ],
        "0 hour ago": [
            "ਇਸ ਘੰਟੇ"
        ],
        "0 minute ago": [
            "ਇਸ ਮਿੰਟ"
        ],
        "0 second ago": [
            "ਹੁਣ"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) ਸਾਲ ਵਿੱਚ",
            "(\\d+) ਸਾਲਾਂ ਵਿੱਚ"
        ],
        "\\1 year ago": [
            "(\\d+) ਸਾਲ ਪਹਿਲਾਂ"
        ],
        "in \\1 month": [
            "(\\d+) ਮਹੀਨੇ ਵਿੱਚ",
            "(\\d+) ਮਹੀਨਿਆਂ ਵਿੱਚ"
        ],
        "\\1 month ago": [
            "(\\d+) ਮਹੀਨਾ ਪਹਿਲਾਂ",
            "(\\d+) ਮਹੀਨੇ ਪਹਿਲਾਂ"
        ],
        "in \\1 week": [
            "(\\d+) ਹਫ਼ਤੇ ਵਿੱਚ",
            "(\\d+) ਹਫ਼ਤਿਆਂ ਵਿੱਚ"
        ],
        "\\1 week ago": [
            "(\\d+) ਹਫ਼ਤਾ ਪਹਿਲਾਂ",
            "(\\d+) ਹਫ਼ਤੇ ਪਹਿਲਾਂ"
        ],
        "in \\1 day": [
            "(\\d+) ਦਿਨ ਵਿੱਚ",
            "(\\d+) ਦਿਨਾਂ ਵਿੱਚ"
        ],
        "\\1 day ago": [
            "(\\d+) ਦਿਨ ਪਹਿਲਾਂ"
        ],
        "in \\1 hour": [
            "(\\d+) ਘੰਟੇ ਵਿੱਚ",
            "(\\d+) ਘੰਟਿਆਂ ਵਿੱਚ"
        ],
        "\\1 hour ago": [
            "(\\d+) ਘੰਟਾ ਪਹਿਲਾਂ",
            "(\\d+) ਘੰਟੇ ਪਹਿਲਾਂ"
        ],
        "in \\1 minute": [
            "(\\d+) ਮਿੰਟ ਵਿੱਚ",
            "(\\d+) ਮਿੰਟਾਂ ਵਿੱਚ"
        ],
        "\\1 minute ago": [
            "(\\d+) ਮਿੰਟ ਪਹਿਲਾਂ"
        ],
        "in \\1 second": [
            "(\\d+) ਸਕਿੰਟ ਵਿੱਚ",
            "(\\d+) ਸਕਿੰਟਾਂ ਵਿੱਚ"
        ],
        "\\1 second ago": [
            "(\\d+) ਸਕਿੰਟ ਪਹਿਲਾਂ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/pa.py <==
info = {
    "name": "pa",
    "date_order": "DMY",
    "january": [
        "ਜਨ",
        "ਜਨਵਰੀ"
    ],
    "february": [
        "ਫ਼ਰ",
        "ਫ਼ਰਵਰੀ"
    ],
    "march": [
        "ਮਾਰਚ"
    ],
    "april": [
        "ਅਪ੍ਰੈ",
        "ਅਪ੍ਰੈਲ"
    ],
    "may": [
        "ਮਈ"
    ],
    "june": [
        "ਜੂਨ"
    ],
    "july": [
        "ਜੁਲਾ",
        "ਜੁਲਾਈ"
    ],
    "august": [
        "ਅਗ",
        "ਅਗਸਤ"
    ],
    "september": [
        "ਸਤੰ",
        "ਸਤੰਬਰ"
    ],
    "october": [
        "ਅਕਤੂ",
        "ਅਕਤੂਬਰ"
    ],
    "november": [
        "ਨਵੰ",
        "ਨਵੰਬਰ"
    ],
    "december": [
        "ਦਸੰ",
        "ਦਸੰਬਰ"
    ],
    "monday": [
        "ਸੋਮ",
        "ਸੋਮਵਾਰ"
    ],
    "tuesday": [
        "ਮੰਗਲ",
        "ਮੰਗਲਵਾਰ"
    ],
    "wednesday": [
        "ਬੁੱਧ",
        "ਬੁੱਧਵਾਰ"
    ],
    "thursday": [
        "ਵੀਰ",
        "ਵੀਰਵਾਰ"
    ],
    "friday": [
        "ਸ਼ੁੱਕਰ",
        "ਸ਼ੁੱਕਰਵਾਰ"
    ],
    "saturday": [
        "ਸ਼ਨਿੱਚਰ",
        "ਸ਼ਨਿੱਚਰਵਾਰ"
    ],
    "sunday": [
        "ਐਤ",
        "ਐਤਵਾਰ"
    ],
    "am": [
        "ਪੂਦੁ"
    ],
    "pm": [
        "ਬਾਦੁ"
    ],
    "year": [
        "ਸਾਲ"
    ],
    "month": [
        "ਮਹੀਨਾ"
    ],
    "week": [
        "ਹਫ਼ਤਾ"
    ],
    "day": [
        "ਦਿਨ"
    ],
    "hour": [
        "ਘੰ",
        "ਘੰਟਾ"
    ],
    "minute": [
        "ਮਿੰਟ"
    ],
    "second": [
        "ਸਕਿੰਟ"
    ],
    "relative-type": {
        "0 day ago": [
            "ਅੱਜ"
        ],
        "0 hour ago": [
            "ਇਸ ਘੰਟੇ"
        ],
        "0 minute ago": [
            "ਇਸ ਮਿੰਟ"
        ],
        "0 month ago": [
            "ਇਹ ਮਹੀਨਾ"
        ],
        "0 second ago": [
            "ਹੁਣ"
        ],
        "0 week ago": [
            "ਇਹ ਹਫ਼ਤਾ"
        ],
        "0 year ago": [
            "ਇਹ ਸਾਲ"
        ],
        "1 day ago": [
            "ਬੀਤਿਆ ਕੱਲ੍ਹ"
        ],
        "1 month ago": [
            "ਪਿਛਲਾ ਮਹੀਨਾ"
        ],
        "1 week ago": [
            "ਪਿਛਲਾ ਹਫ਼ਤਾ"
        ],
        "1 year ago": [
            "ਪਿਛਲਾ ਸਾਲ"
        ],
        "in 1 day": [
            "ਭਲਕੇ"
        ],
        "in 1 month": [
            "ਅਗਲਾ ਮਹੀਨਾ"
        ],
        "in 1 week": [
            "ਅਗਲਾ ਹਫ਼ਤਾ"
        ],
        "in 1 year": [
            "ਅਗਲਾ ਸਾਲ"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) ਦਿਨ ਪਹਿਲਾਂ"
        ],
        "\\1 hour ago": [
            "(\\d+) ਘੰਟਾ ਪਹਿਲਾਂ",
            "(\\d+) ਘੰਟੇ ਪਹਿਲਾਂ"
        ],
        "\\1 minute ago": [
            "(\\d+) ਮਿੰਟ ਪਹਿਲਾਂ"
        ],
        "\\1 month ago": [
            "(\\d+) ਮਹੀਨਾ ਪਹਿਲਾਂ",
            "(\\d+) ਮਹੀਨੇ ਪਹਿਲਾਂ"
        ],
        "\\1 second ago": [
            "(\\d+) ਸਕਿੰਟ ਪਹਿਲਾਂ"
        ],
        "\\1 week ago": [
            "(\\d+) ਹਫ਼ਤਾ ਪਹਿਲਾਂ",
            "(\\d+) ਹਫ਼ਤੇ ਪਹਿਲਾਂ"
        ],
        "\\1 year ago": [
            "(\\d+) ਸਾਲ ਪਹਿਲਾਂ"
        ],
        "in \\1 day": [
            "(\\d+) ਦਿਨ ਵਿੱਚ",
            "(\\d+) ਦਿਨਾਂ ਵਿੱਚ"
        ],
        "in \\1 hour": [
            "(\\d+) ਘੰਟਿਆਂ ਵਿੱਚ",
            "(\\d+) ਘੰਟੇ ਵਿੱਚ"
        ],
        "in \\1 minute": [
            "(\\d+) ਮਿੰਟ ਵਿੱਚ",
            "(\\d+) ਮਿੰਟਾਂ ਵਿੱਚ"
        ],
        "in \\1 month": [
            "(\\d+) ਮਹੀਨਿਆਂ ਵਿੱਚ",
            "(\\d+) ਮਹੀਨੇ ਵਿੱਚ"
        ],
        "in \\1 second": [
            "(\\d+) ਸਕਿੰਟ ਵਿੱਚ",
            "(\\d+) ਸਕਿੰਟਾਂ ਵਿੱਚ"
        ],
        "in \\1 week": [
            "(\\d+) ਹਫ਼ਤਿਆਂ ਵਿੱਚ",
            "(\\d+) ਹਫ਼ਤੇ ਵਿੱਚ"
        ],
        "in \\1 year": [
            "(\\d+) ਸਾਲ ਵਿੱਚ",
            "(\\d+) ਸਾਲਾਂ ਵਿੱਚ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
